@@ -154,43 +154,76 @@ sub _prepare_multicheck_message {
     my $error_stat = shift;
 
     my $summary;
+    my $labels = $self->{multi_check_labels} || {};
     my $nr_checks = scalar(@{$self->{checks}});
     if ($code eq OK) {
-        $summary = "All " . $nr_checks . " checks OK";
+        $summary = $self->_format_multicheck_ok_summary($labels->{summary_ok} ||
+                                                        "All %n checks OK",$nr_checks);
     } else {
-        my $nr_warnings = scalar(@{$np->messages->{warning} || []});
-        my $nr_errors = scalar(@{$np->messages->{critical} || []});
-        my @parts;
-        my $extra = "";
-        my $nr = 0;
-        for my $code (CRITICAL,WARNING,UNKNOWN) {
-            if (my $errs = $error_stat->{$code}) {
-                $extra .= scalar(@$errs) . " " . $STATUS_TEXT{$code} . " (" . join (",",@$errs) . "), ";
-                $nr += scalar(@$errs);
-            }
-        }
-        if ($nr > 0) {
-            # Cut off extra chars at the end
-            $extra = substr($extra,0,-2);
-        }
-        $summary = $nr . " of " . $nr_checks . " failed: " . $extra;
+        $summary = $self->_format_multicheck_failure_summary($labels->{summary_failure} ||
+                                                             "%e of %n checks failed [%d]",
+                                                             $nr_checks,
+                                                             $error_stat);
     }
     return ($code,$summary . "\n" . $message);
 }
 
+sub _format_multicheck_ok_summary {
+    my $self = shift;
+    my $format = shift;
+    my $nr_checks = shift;
+    my $ret = $format;
+    $ret =~ s/\%n/$nr_checks/g;
+    return $ret;
+}
+
+sub _format_multicheck_failure_summary {
+    my $self = shift;
+    my $format = shift;
+    my $nr_checks = shift;
+    my $error_stat = shift;
+
+    my $ret = $format;
+
+    my $details = "";
+    my $total_errors = 0;
+    for my $code (CRITICAL,WARNING,UNKNOWN) {
+        if (my $errs = $error_stat->{$code}) {
+            $details .= scalar(@$errs) . " " . $STATUS_TEXT{$code} . " (" . join (",",@$errs) . "), ";
+            $total_errors += scalar(@$errs);
+        }
+    }
+    if ($total_errors > 0) {
+        # Cut off extra chars at the end
+        $details = substr($details,0,-2);
+    }
+    
+    $ret =~ s/\%d/$details/g;
+    $ret =~ s/\%e/$total_errors/g;
+    $ret =~ s/\%n/$nr_checks/g;
+    return $ret;
+}
+
 # Create a formatted prefix for multicheck output
 sub _multi_check_prefix {
     my $self = shift;
     my $check = shift;
     my $idx = shift;
     my $max = shift;
-    my $label = $check->{config}->{key} || $check->{config}->{name} || "";
+    
+    my $c = $check->{config};
+
     my $l = length($max);
+    
+    return sprintf("[%$l.${l}s] %%c ",$idx)
+      if (defined($c->{multicheckprefix}) && !length($c->{multicheckprefix}));
+    
+    my $label =  $c->{multicheckprefix} || $c->{name} || $c->{key} || "";
     return sprintf("[%$l.${l}s] %%c %s: ",$idx,$label);
 }
 
 
-# Sendp the requests via the build up agent
+# Send the requests via the build up agent
 sub _send_requests {
     my ($self,$jmx,@requests) = @_;
     my $o = $self->{opts};
@@ -305,10 +338,11 @@ sub _verify_and_initialize {
 
     # Fetch configuration
     my $config = $self->_get_config($o->config);
-    
     # Now, if a specific check is given, extract it, too.
     my $check_configs;
+    #print Dumper($config);
     $check_configs = $self->_extract_checks($config,$o->check);
+    #print Dumper($check_configs);
     if ($check_configs) {
         for my $c (@$check_configs) {
             my $s_c = new JMX::Jmx4Perl::Nagios::SingleCheck($np,$c);
@@ -330,17 +364,9 @@ sub _verify_and_initialize {
         my $name = $check->name ? " [Check: " . $check->name . "]" : "";
         $self->nagios_die("An MBean name and a attribute/operation must be provided " . $name)
           if ((!$check->mbean || (!$check->attribute && !$check->operation)) && !$check->alias && !$check->value && !$check->script);
-        $self->verify_check($check,$name);
     }
 }
 
-sub verify_check {
-    my $self = shift;
-    my $check = shift;
-    my $name = shift;
-    my $np = $self->{np};
-}
-
 # Extract one or more check configurations which can be 
 # simple <Check>s or <MultiCheck>s
 sub _extract_checks {
@@ -352,10 +378,11 @@ sub _extract_checks {
     if ($check) {
         $self->nagios_die("No configuration given") unless $config;
         $self->nagios_die("No checks defined in configuration") unless $config->{check};
-        
+
         my $check_configs;
         unless ($config->{check}->{$check}) {
             $check_configs = $self->_resolve_multicheck($config,$check,$self->{cmd_args});
+            $self->_retrieve_mc_summary_label($config,$check);
         } else {
             my $check_config = $config->{check}->{$check};
             $check_configs = ref($check_config) eq "ARRAY" ? $check_config : [ $check_config ];
@@ -363,17 +390,19 @@ sub _extract_checks {
         }
         $self->nagios_die("No check configuration with name " . $check . " found") unless (@{$check_configs});
 
+        #print Dumper($check_configs);
+
         # Resolve parent values
         for my $c (@{$check_configs}) {
-            # print "[A] ",Dumper($c);
+            #print "[A] ",Dumper($c);
             $self->_resolve_check_config($c,$config,$self->{cmd_args});
             
-            # print "[B] ",Dumper($c);
+            #print "[B] ",Dumper($c);
             # Finally, resolve any left over place holders
             for my $k (keys(%$c)) {
                 $c->{$k} = $self->_replace_placeholder($c->{$k},undef) unless ref($c->{$k});
             }
-            # print "[C] ",Dumper($c);
+            #print "[C] ",Dumper($c);
         }
         return $check_configs;
     } else {
@@ -422,6 +451,24 @@ sub _resolve_multicheck {
     return $check_config;
 }
 
+sub _retrieve_mc_summary_label { 
+    my $self = shift;
+    my $config = shift;
+    my $check = shift;
+
+    my $multi_checks = $config->{multicheck};    
+    if ($multi_checks) { 
+        my $m_check = $multi_checks->{$check};
+        if ($m_check && ($m_check->{summaryok} || $m_check->{summaryfailure})) {
+            my $mc_labels = 
+            $self->{multi_check_labels} = {
+                                           summary_ok => $m_check->{summaryok},
+                                           summary_failure => $m_check->{summaryfailure}
+                                          };
+        }
+    }
+}
+
 sub _merge_multicheck_args {
     my $self = shift;
     my $check_params = shift;
@@ -474,7 +521,7 @@ sub _resolve_check_config {
         }
         # Replace inherited values
         for my $k (keys %$parent_merged) {
-            my $parent_val = $parent_merged->{$k} || "";
+            my $parent_val = defined($parent_merged->{$k}) ?  $parent_merged->{$k} :  "";
             if (defined($check->{$k})) {
                 $check->{$k} =~ s/\$BASE/$parent_val/g;
             } else {
@@ -534,8 +581,8 @@ EOP
         my $orig_val = '$' . $2;
         my $i = defined($3) ? $3 : $4;
         my $default = $5;
-        $default =~ s/^\s*(.*)+?\s*$/$1/ if $default; # Trim whitespace
         my $end = defined($6) ? $6 : "";
+        $default =~ s/^\s*(.*)+?\s*$/$1/ if $default; # Trim whitespace
         #print Dumper({start => $start, orig => $orig_val,end => $end, default=> $default, rest => $rest, i => $i}); 
         if (defined($args)) {
             my $repl = $args->[$i];            
@@ -580,7 +627,7 @@ EOP
 sub _parse_check_ref {
     my $self = shift;
     my $check_ref = shift;
-    if ($check_ref =~/^\s*([^(]+)\(([^)]*)\)\s*$/) {
+    if ($check_ref =~/^\s*(.+?)\((.*)\)\s*$/) {
         my $name = $1;
         my $args_s = $2;
         my $args = [ parse_line('\s*,\s*',0,$args_s) ];
