@@ -96,7 +96,11 @@ sub get_requests {
     if ($self->base || $self->base_mbean) {
         if (!looks_like_number($self->base)) {
             # It looks like a number, so we will use the base literally
-            my $alias = JMX::Jmx4Perl::Alias->by_name($self->base);
+            my $alias;
+            
+            if ($self->base) {
+                $alias = JMX::Jmx4Perl::Alias->by_name($self->base);
+            }
             if ($alias) {
                 push @requests,new JMX::Jmx4Perl::Request(READ,$jmx->resolve_alias($self->base));
             } else {
@@ -212,7 +216,7 @@ sub extract_responses {
         $self->_update_error_stats($opts->{error_stat},$code) unless $code == OK;
         my ($base_conv,$base_unit) = $self->_normalize_value($base_value);
         $np->add_message($code,$self->_exit_message(code => $code,mode => $mode,rel_value => $rel_value, 
-                                                    value => $value_conv, unit => $unit,base => $base_conv, 
+                                                    value => $value_conv, unit => $unit, base => $base_conv, 
                                                     base_unit => $base_unit, prefix => $opts->{prefix}));            
     } else {
         # Performance data
@@ -360,6 +364,7 @@ sub _base_value {
     my $resp = shift @{$responses};
     my $req = shift @{$requests};
     $self->nagios_die($resp->{error}) if $resp->{error};
+    #print Dumper($req,$resp);
     return $self->_extract_value($req,$resp);
 }
 
@@ -436,9 +441,11 @@ sub _verify_response {
     my ($self,$req,$resp) = @_;
     my $np = $self->{np};
     if ($resp->is_error) {
-        my $stacktrace = $resp->stacktrace;
         my $extra = "";
-        $extra = ref($stacktrace) eq "ARRAY" ? join "\n",@$stacktrace : $stacktrace if $stacktrace;
+        if ($np->opts->{verbose}) {
+            my $stacktrace = $resp->stacktrace;
+            $extra = ref($stacktrace) eq "ARRAY" ? join "\n",@$stacktrace : $stacktrace if $stacktrace;
+        }
         $self->nagios_die("Error: ".$resp->status." ".$resp->error_text.$extra);
     }
     
@@ -463,7 +470,7 @@ sub _get_name {
             } else {
                 my $val = $self->value;
                 if ($val) {
-                    $name = "[" . $self->value . "]";
+                    $name = "[" . $val . "]";
                 } else {
                     my $a_or_o = $self->attribute || $self->operation || "";
                     my $p = $self->path ? "," . $self->path : "";
@@ -510,7 +517,8 @@ sub _prepare_exec_args {
     # Merge CLI arguments and arguments from the configuration,
     # with CLI arguments taking precedence
     my @cli_args = @_;
-    my $config_args = $self->{config}->{args};
+    my $config_args = $self->{config}->{argument};
+    $config_args = [ $config_args ] unless ref($config_args) eq "ARRAY";
     my @args = ();
     if ($config_args) {
         my @c_args = (@$config_args);
@@ -544,7 +552,7 @@ sub _split_attr_spec {
         $p =~ s|\\(.)|$1|sg;
         push @ret,$p;
     }    
-    return @ret;
+    return (shift(@ret),shift(@ret),@ret ? join("/",@ret) : undef);
 }
 
 sub _check_threshold {
@@ -563,7 +571,8 @@ sub _check_threshold {
           (
            defined($self->critical) ? (critical => $self->critical) : (),
            defined($self->warning) ? (warning => $self->warning) : ()
-          );            
+          );  
+        #print Dumper({check => $value,@ths});
         return (@ths ? $np->check_threshold(check => $value,@ths) : OK,"numeric");    
     } else {
         return
@@ -610,7 +619,7 @@ sub _exit_message {
     my $code = $args->{code};
     my $mode = $args->{mode};
     if ($code == CRITICAL || $code == WARNING) {
-        if ($self->base) {
+        if ($self->base || $self->base_mbean) {
             return $self->_format_label
               ('%n : Threshold \'%t\' failed for value %.2r% ('. &_placeholder($args,"v") .' %u / '.
                &_placeholder($args,"b") . ' %u)',$args);
@@ -623,7 +632,7 @@ sub _exit_message {
             }
         }
     } else {
-        if ($self->base) {
+        if ($self->base || $self->base_mbean) {
             return $self->_format_label('%n : In range %.2r% ('. &_placeholder($args,"v") .' %u / '.
                                         &_placeholder($args,"b") . ' %w)',$args);
         } else {
@@ -652,10 +661,13 @@ sub _format_label {
     my $self = shift;
     my $label = shift;
     my $args = shift;
-    # %r : relative value
+    # %r : relative value (as percent)
+    # %q : relative value (as floating point)
     # %v : value
+    # %f : value as floating point
     # %u : unit
     # %b : base value
+    # %w : base unit
     # %t : threshold failed ("" for OK or UNKNOWN)
     # %c : code ("OK", "WARNING", "CRITICAL", "UNKNOWN")
     # %d : delta
@@ -665,8 +677,10 @@ sub _format_label {
     foreach my $p (@parts) {
         if ($p =~ /^(\%[\w\.\-]*)(\w)$/) {
             my ($format,$what) = ($1,$2);
-            if ($what eq "r") {
-                $ret .= sprintf $format . "f",($args->{rel_value} || 0);
+            if ($what eq "r" || $what eq "q") {
+                my $val = $args->{rel_value} || 0;
+                $val = $what eq "r" ? $val : $val / 100; 
+                $ret .= sprintf $format . "f",$val;
             } elsif ($what eq "b") {
                 $ret .= sprintf $format . &_format_char($args->{base}),($args->{base} || 0);
             } elsif ($what eq "u" || $what eq "w") {
